@@ -5,15 +5,8 @@ function(out,no.col=FALSE,standard=TRUE)
 {  
   Wstart<-out$ValW[1]
   Wend<-out$ValW[2]
-  ##  out is output of 'JOP'
   if(no.col==FALSE)
   {
-    ## Warning Messages:
-    if(is.null(out))
-    {
-      return("Run 'JOP' first! 'oplot' needs output of 'JOP'!")
-    }
-  
     ## Setting Values
     nx<-dim(out[[1]])[2]
     ny<-dim(out[[2]])[2]
@@ -31,7 +24,6 @@ function(out,no.col=FALSE,standard=TRUE)
     ## Values to label the axes
     xaxis1<-1:numbW
     xaxis2<-1:(numbW+ny-1)
-    xaxis1names<-paste("W",xaxis1,sep="")
     yaxis1<-seq(-round(max(abs(optmatrix)),digits=3),round(max(abs(optmatrix)),digits=3),round(max(abs(optmatrix)),digits=3))
   
     # left plot
@@ -53,17 +45,25 @@ function(out,no.col=FALSE,standard=TRUE)
     devstand<-matrix(NaN,ncol=ny,nrow=numbW)
     for(i in 1:ny)
     {
-      reoptplot[,i]<-reoptmatrix[,i]/max(reoptmatrix[,i])
+      for(j in 1:numbW)
+      {
+        reoptplot[j,i]<-ifelse(tau[i]>max(reoptmatrix[,i]),reoptmatrix[j,i]/tau[i],reoptmatrix[j,i]/max(reoptmatrix[,i]))
+      }
       devstand[,i]<-deviation[,i]/max(reoptmatrix[,i])
     }
   
     # right Plot
-  
+    axis4<-NULL
+    for(i in 1:ny)
+    {
+      axis4[i]<-ifelse(tau[i]>max(reoptmatrix[,i]),1,tau[i]/max(reoptmatrix[,i]))
+    }
     par(fig=c(0.5,0.95,0.15,0.85),new=TRUE,bty="l",pty="s",las=1)
-    plot(xaxis1,reoptplot[,1],xlab="Stretch Vector",ylab="",ylim=c(0,1.25+max(devstand)),xaxt="n",yaxt="n",pch=NA)
+    plot(xaxis1,reoptplot[,1],xlab="Stretch Vector",ylab="",ylim=c(0.8*min(reoptplot,axis4),1.05+max(devstand)),xaxt="n",yaxt="n",pch=NA)
     mtext("Predicted Response",side=3,at=1,cex=0.6)
     axis(1,at=c(1,1+(numbW-1)/2,numbW),labels=c(Wstart,Wstart+0.5*(Wend-Wstart),Wend))
-    axis(2,at=c(0.25,0.625,1),labels=c("","",""))
+    axis(2,at=c(0.8*min(reoptplot,axis4),0.9*(min(reoptplot,axis4)+0.5*(1-min(reoptplot,axis4))),1),labels=c("","",""))   
+    
       #deviation
     if(standard==TRUE)
     {
@@ -79,8 +79,6 @@ function(out,no.col=FALSE,standard=TRUE)
           point21[i]<-numbW-i+1
           point22[i]<-reoptplot[numbW-i+1,j]+devstand[numbW-i+1,j]
           point12[i]<-reoptplot[i,j]-devstand[i,j]
-          #points(point1,point2,col=cols[nx+j],pch=NA)
-          #lines(point1,point2,col=cols[nx+j])
         }
         point1<-c(point11,point21)
         point2<-c(point12,point22)
@@ -88,48 +86,43 @@ function(out,no.col=FALSE,standard=TRUE)
       }    
 
     
-      lines(xaxis1,reoptplot[,1],col="black")#cols[nx+1])                            
+      lines(xaxis1,reoptplot[,1],col="black")                           
       for(i in 2:ny)
       {
-        #points(xaxis1,reoptplot[,i],col=cols[nx+i],pch=NA)
-        lines(xaxis1,reoptplot[,i],col="black")#cols[nx+i])
+        lines(xaxis1,reoptplot[,i],col="black")
       }
       for(i in 1:ny)
       {
-        mtext(c(round(0.25*max(reoptmatrix[,i]),digits=2),round(0.625*max(reoptmatrix[,i]),digits=2),round(max(reoptmatrix[,i]),digits=2)),side=2,at=c(0.25-(ny-1)*0.035+(i-1)*0.065,0.625-(ny-1)*0.035+(i-1)*0.065,1-(ny-1)*0.045+(i-1)*0.065),col=cols[nx+i],cex=0.6,line=1.2)
-      }
+         mtext(c(round(0.8*min(reoptplot,axis4)*max(reoptmatrix[,i]),digits=2),round(0.9*((min(reoptplot,axis4)+0.5*(1-min(reoptplot,axis4))))*max(reoptmatrix[,i],tau[i]),digits=2),round(max(reoptmatrix[,i],tau[i]),digits=2)),side=2,at=c(0.8*min(reoptplot,axis4)-(ny-1)*0.025+(i-1)*0.025,0.9*(min(reoptplot,axis4)+0.5*(1-min(reoptplot,axis4)))-(ny-1)*0.025+(i-1)*0.025,1-(ny-1)*0.025+(i-1)*0.025),col=cols[nx+i],cex=0.6,line=1.2)
+      } 
     }
     if(standard==FALSE)
     {
       lines(xaxis1,reoptplot[,1],col=cols[nx+1])                            
       for(i in 2:ny)
       {
-        #points(xaxis1,reoptplot[,i],col=cols[nx+i],pch=NA)
         lines(xaxis1,reoptplot[,i],col=cols[nx+i])
       }
       for(i in 1:ny)
       {
-        mtext(c(round(0.25*max(reoptmatrix[,i]),digits=2),round(0.625*max(reoptmatrix[,i]),digits=2),round(max(reoptmatrix[,i]),digits=2)),side=2,at=c(0.25-(ny-1)*0.035+(i-1)*0.065,0.625-(ny-1)*0.035+(i-1)*0.065,1-(ny-1)*0.045+(i-1)*0.065),col=cols[nx+i],cex=0.6,line=1.2)
+         mtext(c(round(0.8*min(reoptplot,axis4)*max(reoptmatrix[,i]),digits=2),round(0.9*((min(reoptplot,axis4)+0.5*(1-min(reoptplot,axis4))))*max(reoptmatrix[,i],tau[i]),digits=2),round(max(reoptmatrix[,i],tau[i]),digits=2)),side=2,at=c(0.8*min(reoptplot,axis4)-(ny-1)*0.025+(i-1)*0.025,0.9*(min(reoptplot,axis4)+0.5*(1-min(reoptplot,axis4)))-(ny-1)*0.025+(i-1)*0.025,1-(ny-1)*0.025+(i-1)*0.025),col=cols[nx+i],cex=0.6,line=1.2)
       }    
     }
       ######################
       ### Target Values ####
       ######################
-          
-      axis4<-NULL
-      for(i in 1:ny)
-      {
-        axis4[i]<-tau[i]/max(reoptmatrix[,i])
-      }
+      
       zaehler<-vector("list",length(tau))
       for(i in 1:length(tau))
       {
       counter<-NULL
+      index<-1
         for(j in 1:length(tau))
-        {
-          if(abs(axis4[i]-axis4[j])<0.065 && i!=j)
+        { 
+          if(abs(axis4[i]-axis4[j])<0.001 && i!=j)
           {
-            counter[i]<-j
+            counter[index]<-j
+            index<-index+1
           }
         }
         zaehler[[i]]<-sort(c(i,counter))
@@ -145,7 +138,7 @@ function(out,no.col=FALSE,standard=TRUE)
             point1<-c(1+(j-1)*(numbW-1)/length(zaehler[[i]]),1+j*(numbW-1)/length(zaehler[[i]]))
             point2<-c(axis4[i],axis4[i])
             lines(point1,point2,col=cols[nx+i])
-            mtext(round(tau[i],digits=2),side=4,at=axis4[i]-(j-1)*0.065,col=cols[nx+i],cex=0.6,line=1.2)
+            mtext(round(tau[i],digits=2),side=4,at=axis4[i]-(j-1)*0.035,col=cols[nx+i],cex=0.6,line=1.2)
           }
         }
       }  
@@ -163,12 +156,6 @@ function(out,no.col=FALSE,standard=TRUE)
   }
   else
   {
-      ## Warning Messages:
-    if(is.null(out))
-    {
-      return("Run 'JOP' first! 'oplot' needs output of 'JOP'!")
-    }
-  
     ## Setting Values
     nx<-dim(out[[1]])[2]
     ny<-dim(out[[2]])[2]
@@ -186,7 +173,6 @@ function(out,no.col=FALSE,standard=TRUE)
     ## Values to label the axes
     xaxis1<-1:numbW
     xaxis2<-1:(numbW+ny-1)
-    xaxis1names<-paste("W",xaxis1,sep="")
     yaxis1<-seq(-round(max(abs(optmatrix)),digits=3),round(max(abs(optmatrix)),digits=3),round(max(abs(optmatrix)),digits=3))
     cols1<-gray(seq(0.5,0.6,length=nx))
     cols3<-gray(seq(0.5,0.6,length=ny))
@@ -198,11 +184,11 @@ function(out,no.col=FALSE,standard=TRUE)
     mtext("Parameter Setting",side=3,at=1,cex=0.6)
     axis(1,at=c(1,1+(numbW-1)/2,numbW),labels=c(Wstart,Wstart+0.5*(Wend-Wstart),Wend))
     axis(2,at=yaxis1)
-    lines(xaxis1,optmatrix[,1],lty=1,col=cols3[1])        
+    lines(xaxis1,optmatrix[,1],lty=1,col=cols3[1])      
     for(i in 2:nx)
     {  
       points(xaxis1,optmatrix[,i],pch=NA)
-      lines(xaxis1,optmatrix[,i],lty=i,col=cols3[i])
+      lines(xaxis1,optmatrix[,i],lty=i,col=cols1[i])
     }
     legend("topright",dimnames(out$Parameters)[[2]],lty=1:nx,bty="n",lwd=1)
   
@@ -214,18 +200,25 @@ function(out,no.col=FALSE,standard=TRUE)
     devstand<-matrix(NaN,ncol=ny,nrow=numbW)
     for(i in 1:ny)
     {
-      reoptplot[,i]<-reoptmatrix[,i]/max(reoptmatrix[,i])
+      for(j in 1:numbW)
+      {
+        reoptplot[j,i]<-ifelse(tau[i]>max(reoptmatrix[,i]),reoptmatrix[j,i]/tau[i],reoptmatrix[j,i]/max(reoptmatrix[,i]))
+      }
       devstand[,i]<-deviation[,i]/max(reoptmatrix[,i])
     }
 
   
 
-  
+    axis4<-NULL
+    for(i in 1:ny)
+    {
+      axis4[i]<-ifelse(tau[i]>max(reoptmatrix[,i]),1,tau[i]/max(reoptmatrix[,i]))
+    }
     par(fig=c(0.5,0.95,0.15,0.85),new=TRUE,bty="l",pty="s",las=1)
-    plot(xaxis1,reoptplot[,1],xlab="Stretch Vector",ylab="",ylim=c(0,1.25+max(devstand)),xaxt="n",yaxt="n",pch=NA)
+    plot(xaxis1,reoptplot[,1],xlab="Stretch Vector",ylab="",ylim=c(0.8*min(reoptplot,axis4),1.05+max(devstand)),xaxt="n",yaxt="n",pch=NA)
     mtext("Predicted Response",side=3,at=1,cex=0.6)
     axis(1,at=c(1,1+(numbW-1)/2,numbW),labels=c(Wstart,Wstart+0.5*(Wend-Wstart),Wend))
-    axis(2,at=c(0.25,0.625,1),labels=c("","",""))
+    axis(2,at=c(0.8*min(reoptplot,axis4),0.9*(min(reoptplot,axis4)+0.5*(1-min(reoptplot,axis4))),1),labels=c("","",""))
 
     
 
@@ -244,28 +237,26 @@ function(out,no.col=FALSE,standard=TRUE)
         point21[i]<-numbW-i+1
         point22[i]<-reoptplot[numbW-i+1,j]+devstand[numbW-i+1,j]
         point12[i]<-reoptplot[i,j]-devstand[i,j]
-        #points(point1,point2,col=cols[nx+j],pch=NA)
-        #lines(point1,point2,col=cols[nx+j])
       }
       point1<-c(point11,point21)
       point2<-c(point12,point22)
       polygon(point1,point2,col=cols2[j],border=FALSE)
       }
           
-      lines(xaxis1,reoptplot[,1],lty=1,col=cols3[1])#cols2[1])#cols[nx+1])                            
+      lines(xaxis1,reoptplot[,1],lty=1,col=cols3[1])                           
       for(i in 2:ny)
       {
         points(xaxis1,reoptplot[,i],pch=NA)
-        lines(xaxis1,reoptplot[,i],lty=i,col=cols3[i])#=cols2[i])
+        lines(xaxis1,reoptplot[,i],lty=i,col=cols3[i])
       }
       for(i in 1:ny)
       {
-        mtext(c(round(0.25*max(reoptmatrix[,i]),digits=2),round(0.625*max(reoptmatrix[,i]),digits=2),round(max(reoptmatrix[,i]),digits=2)),side=2,at=c(0.25-(ny-1)*0.035+(i-1)*0.065,0.625-(ny-1)*0.035+(i-1)*0.065,1-(ny-1)*0.045+(i-1)*0.065),col=cols3[i],cex=0.6,line=1.2)
+        mtext(c(round(0.8*min(reoptplot,axis4)*max(reoptmatrix[,i]),digits=2),round(0.9*((min(reoptplot,axis4)+0.5*(1-min(reoptplot,axis4))))*max(reoptmatrix[,i],tau[i]),digits=2),round(max(reoptmatrix[,i],tau[i]),digits=2)),side=2,at=c(0.8*min(reoptplot,axis4)-(ny-1)*0.025+(i-1)*0.025,0.9*(min(reoptplot,axis4)+0.5*(1-min(reoptplot,axis4)))-(ny-1)*0.025+(i-1)*0.025,1-(ny-1)*0.025+(i-1)*0.025),col=cols3[i],cex=0.6,line=1.2)
       }
     }
     if(standard==FALSE)
     {
-      lines(xaxis1,reoptplot[,1],col=cols3[1],lty=1)#cols[nx+1])                            
+      lines(xaxis1,reoptplot[,1],col=cols3[1],lty=1)                            
       for(i in 2:ny)
       {
         points(xaxis1,reoptplot[,i],pch=NA)
@@ -273,25 +264,20 @@ function(out,no.col=FALSE,standard=TRUE)
       }
       for(i in 1:ny)
       {
-        mtext(c(round(0.25*max(reoptmatrix[,i]),digits=2),round(0.625*max(reoptmatrix[,i]),digits=2),round(max(reoptmatrix[,i]),digits=2)),side=2,at=c(0.25-(ny-1)*0.035+(i-1)*0.065,0.625-(ny-1)*0.035+(i-1)*0.065,1-(ny-1)*0.045+(i-1)*0.065),col=cols3[i],cex=0.6,line=1.2)
+        mtext(c(round(0.8*min(reoptplot,axis4)*max(reoptmatrix[,i]),digits=2),round(0.9*((min(reoptplot,axis4)+0.5*(1-min(reoptplot,axis4))))*max(reoptmatrix[,i],tau[i]),digits=2),round(max(reoptmatrix[,i],tau[i]),digits=2)),side=2,at=c(0.8*min(reoptplot,axis4)-(ny-1)*0.025+(i-1)*0.025,0.9*(min(reoptplot,axis4)+0.5*(1-min(reoptplot,axis4)))-(ny-1)*0.025+(i-1)*0.025,1-(ny-1)*0.025+(i-1)*0.025),col=cols3[i],cex=0.6,line=1.2)
       }    
     }
     ######################
     ### Target Values ####
     ######################
         
-    axis4<-NULL
-    for(i in 1:ny)
-    {
-      axis4[i]<-tau[i]/max(reoptmatrix[,i])
-    }
     zaehler<-vector("list",length(tau))
     for(i in 1:length(tau))
     {
     counter<-NULL
       for(j in 1:length(tau))
       {
-        if(abs(axis4[i]-axis4[j])<0.065 && i!=j)
+        if(abs(axis4[i]-axis4[j])<0.001 && i!=j)
         {
           counter[i]<-j
         }
@@ -309,7 +295,7 @@ function(out,no.col=FALSE,standard=TRUE)
           point1<-c(1+(j-1)*(numbW-1)/length(zaehler[[i]]),1+j*(numbW-1)/length(zaehler[[i]]))
           point2<-c(axis4[i],axis4[i])
           lines(point1,point2,col=cols3[i],lty=i)
-          mtext(round(tau[i],digits=2),side=4,at=axis4[i]-(j-1)*0.065,col=cols3[i],cex=0.6,line=1.2)
+          mtext(round(tau[i],digits=2),side=4,at=axis4[i]-(j-1)*0.035,col=cols3[i],cex=0.6,line=1.2)
         }
       }
     }  
@@ -323,7 +309,7 @@ function(out,no.col=FALSE,standard=TRUE)
     {
       nam[i]<-paste(paste(paste(nam[i],";",sep=""),"target",sep=" "),tau[i],sep="=") 
     }
-    legend("topright",nam,col=cols3,lty=1:ny,bty="n",lwd=1)#1.25+max(devstand)
+    legend("topright",nam,col=cols3,lty=1:ny,bty="n",lwd=1)
   }
   return("Plot is done!")
 }
